@@ -228,7 +228,7 @@ symbol (not a form)."
   ;; If the second line is already empty, do nothing.
   (should
    (equal (helpful--split-first-line "foo.\n\nbar") "foo.\n\nbar"))
-  ;; But if we have a single sentence and no empy line, insert one.
+  ;; But if we have a single sentence and no empty line, insert one.
   (should
    (equal (helpful--split-first-line "foo.\nbar") "foo.\n\nbar")))
 
@@ -316,6 +316,27 @@ symbol (not a form)."
          (paren-position (s-index-of "(" formatted)))
     (should
      (string-equal formatted "Info node (elisp)foo \nbar"))
+    (should
+     (get-text-property paren-position 'button formatted)))
+  ;; Some docstrings use "info" (lowercase).
+  (let* ((formatted (helpful--format-docstring "info node `(elisp)foo'"))
+         (paren-position (s-index-of "(" formatted)))
+    (should
+     (string-equal formatted "info node (elisp)foo"))
+    (should
+     (get-text-property paren-position 'button formatted)))
+  ;; Some docstrings use angular quotation marks.
+  (let* ((formatted (helpful--format-docstring "Info node ‘(elisp)foo’"))
+         (paren-position (s-index-of "(" formatted)))
+    (should
+     (string-equal formatted "Info node (elisp)foo"))
+    (should
+     (get-text-property paren-position 'button formatted)))
+  ;; If there's no manual information, assume it is part of the Emacs manual.
+  (let* ((formatted (helpful--format-docstring "Info node ‘foo’"))
+         (paren-position (s-index-of "(" formatted)))
+    (should
+     (string-equal formatted "Info node (emacs)foo"))
     (should
      (get-text-property paren-position 'button formatted))))
 
@@ -533,6 +554,20 @@ associated a lambda with a keybinding."
     (with-current-buffer buf
       (helpful-update))))
 
+(ert-deftest helpful--unnamed-compiled-func ()
+  "Ensure we handle unnamed byte-compiled functions.
+
+This is important for `helpful-key', where a user may have
+associated a lambda with a keybinding."
+  (let* ((fun (byte-compile (lambda (x) x)))
+         (buf (helpful--buffer fun t)))
+    ;; There's no name, so just show lambda in the buffer name.
+    (should
+     (equal (buffer-name buf) "*helpful lambda*"))
+    ;; Don't crash when we show the buffer.
+    (with-current-buffer buf
+      (helpful-update))))
+
 (ert-deftest helpful--obsolete-variable ()
   "Test display of obsolete variable."
   (let* ((var 'helpful-test-var-obsolete)
@@ -782,6 +817,34 @@ find the source code."
     (should
      (s-starts-with-p "if is a special form defined in" summary))))
 
+(defun helpful-test-fn-interactive ()
+  (interactive))
+
+(ert-deftest helpful--summary--interactive-fn ()
+  "Ensure we use \"an\" for interactive functions."
+  (let* ((summary (helpful--summary 'helpful-test-fn-interactive t nil nil)))
+    ;; Strip properties to make assertion messages more readable.
+    (set-text-properties 0 (1- (length summary)) nil summary)
+    (should
+     (s-starts-with-p "helpful-test-fn-interactive is an interactive function" summary))))
+
+(defun helpful-test-fn? ()
+  (interactive))
+
+(ert-deftest helpful--summary--fn-with-? ()
+  "Ensure we use don't needlessly escape ? in function names."
+  (let* ((summary (helpful--summary 'helpful-test-fn? t nil nil)))
+    ;; Strip properties to make assertion messages more readable.
+    (set-text-properties 0 (1- (length summary)) nil summary)
+    (should
+     (s-starts-with-p "helpful-test-fn? is" summary))))
+
+(ert-deftest helpful--signature-fn-with? ()
+  "Ensure that symbols with question marks are handled correctly."
+  (should
+   (equal (helpful--signature 'helpful-test-fn?)
+          "(helpful-test-fn?)")))
+
 (defun helpful-test-fn-with\ space ()
   42)
 
@@ -908,11 +971,12 @@ find the source code."
       (goto-char (point-min))
       (push-button))))
 
-(ert-deftest helpful--autoloaded-p ()
-  (-let [(buf pos opened) (helpful--definition 'rx-to-string t)]
-    (should (helpful--autoloaded-p 'rx-to-string buf))
-    (when opened
-      (kill-buffer buf))))
+;; TODO: broken when byte-compiling helpful.el.
+;; (ert-deftest helpful--autoloaded-p ()
+;;   (-let [(buf pos opened) (helpful--definition 'rx-to-string t)]
+;;     (should (helpful--autoloaded-p 'rx-to-string buf))
+;;     (when opened
+;;       (kill-buffer buf))))
 
 (ert-deftest helpful--inhibit-read-only ()
   (helpful-variable 'inhibit-read-only)
@@ -933,6 +997,10 @@ find the source code."
   (should-not
    (helpful--convert-c-name 'Vgc_cons_percentage nil)))
 
+(ert-deftest helpful-symbol-c-style ()
+  (helpful-symbol 'Fget_char_property)
+  (helpful-symbol 'Vinhibit_field_text_motion))
+
 (ert-deftest helpful-symbol-unbound ()
   "Ensure we inform the user if we're given an unbound symbol."
   (should
@@ -950,3 +1018,35 @@ find the source code."
   ;; loaded.
   ;;
   (helpful-function #'tetris))
+
+(defcustom helpful-test-custom-var 123
+  "I am an example custom variable."
+  :type 'number
+  :group 'helpful
+  :package-version '(helpful . "1.2.3"))
+
+;; Ensure the current value differs from the original value.
+(setq helpful-test-custom-var 456)
+
+(ert-deftest helpful--original-value ()
+  "Show the original value for defcustom variables."
+  (helpful-variable 'helpful-test-custom-var)
+  (should
+   (s-contains-p "Original Value\n123" (buffer-string))))
+
+(ert-deftest helpful--package-version ()
+  "Report when a variable was added"
+  (helpful-variable 'helpful-test-custom-var)
+  (should
+   (s-contains-p
+    (s-word-wrap
+     70
+     "This variable was added, or its default value changed, in helpful version 1.2.3.")
+    (buffer-string))))
+
+(ert-deftest helpful--display-implementations ()
+  (require 'xref)
+  (helpful-function 'xref-location-marker)
+  (should (s-contains-p "Implementations" (buffer-string)))
+  (should (s-contains-p "((l xref-file-location))" (buffer-string)))
+  (should (s-contains-p "((l xref-buffer-location))" (buffer-string))))
